# kdock


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Installation

Install latest from the GitHub
[repository](https://github.com/sky1ove/kdock):

``` sh
$ pip install -U git+https://github.com/sky1ove/kdock.git
```

### Documentation

Documentation can be found hosted on this GitHub
[repository](https://github.com/sky1ove/kdock)’s
[pages](https://sky1ove.github.io/kdock/). Additionally you can find
package manager specific guidelines on
[conda](https://anaconda.org/sky1ove/kdock) and
[pypi](https://pypi.org/project/kdock/) respectively.

## Quick start

Todo
